@@ -6,6 +6,7 @@ from pydantic import BaseModel, ValidationError
 from pydantic.fields import FieldInfo, ModelField
 from typing import Any, Dict, List, Mapping, Optional, Union, Generator
 
+
 from .dispatchers import are_equal
 from .indexes import BaseIndex, Index, MultiIndex
 from .interfaces import get_interface
@@ -40,6 +41,19 @@ class BaseSchema(BaseModel):
                 raise ValueError(f"Field name '{name}' is reserved and cannot be used.")
         return super().__init_subclass__()
 
+    @classmethod
+    def register_datasource(cls, datasource, name='data'):
+        """Register a datasource with this schema
+        """
+
+        if hasattr(cls, name):
+            raise ValueError(f"Datasource name '{name}' is already registered.")
+            
+        from rframe.data_accessor import DataAccessor
+
+        accessor = DataAccessor(cls, datasource)
+        setattr(cls, name, accessor)
+
     @classmethod
     def default_datasource(cls):
         return cls.empty_dframe()
@@ -67,7 +81,8 @@ class BaseSchema(BaseModel):
     @classmethod
     def get_query_signature(cls, default=None):
         params = []
-        for name in cls.__fields__:
+        for name, field in cls.__fields__.items():
+            alias = field.alias
             for type_ in cls.mro():
                 if name in getattr(type_, "__annotations__", {}):
                     label_annotation = type_.__annotations__[name]
@@ -83,9 +98,21 @@ class BaseSchema(BaseModel):
                         inspect.Parameter.POSITIONAL_OR_KEYWORD,
                         default=default,
                         annotation=annotation,
-                    )
+                        )
                     params.append(param)
+
+                    if name == alias:
+                        break
+
+                    alias_param = param = inspect.Parameter(
+                        alias,
+                        inspect.Parameter.POSITIONAL_OR_KEYWORD,
+                        default=default,
+                        annotation=annotation,
+                        )
+                    params.append(alias_param)
                     break
+                
         return inspect.Signature(params)
 
     @classmethod
